==> 2205.0.tar.gz: o3de/Code/Framework/AzCore/AzCore/Script/ScriptAsset.h <==
/*
 * Copyright (c) Contributors to the Open 3D Engine Project.
 * For complete copyright and license terms please see the LICENSE at the root of this distribution.
 *
 * SPDX-License-Identifier: Apache-2.0 OR MIT
 *
 */
#pragma once

#include <AzCore/Asset/AssetCommon.h>
#include <AzCore/IO/GenericStreams.h>
#include <AzCore/IO/ByteContainerStream.h>
#include <AzCore/std/containers/vector.h>

namespace UnitTest
{
    class ScriptComponentTest;
}

namespace AZ
{
    /**
    * Script Asset - contains the source code for a script
    */
    class ScriptAsset
        : public Data::AssetData
    {
    public:
        AZ_CLASS_ALLOCATOR(ScriptAsset, AZ::SystemAllocator, 0);
        AZ_RTTI(ScriptAsset, "{82557326-4AE3-416C-95D6-C70635AB7588}", Data::AssetData);

        enum : u32
        {
            // Asset sub-ids
            CompiledAssetSubId = 1,
            CopiedAssetSubId = 2,
        };

        enum LuaScriptInfo : u8 // u8 to avoid endian issues
        {
            // Current latest-asset version
            AssetVersion = 3,

            // Asset type field for Lua bytecode files
            AssetTypeCompiled = 0,
            // Asset type field for Lua text files
            AssetTypeText = 1,

            // Used to initialize fields that will be read in
            Invalid = UCHAR_MAX,
        };

        ScriptAsset(const Data::AssetId& assetId = Data::AssetId());
        ~ScriptAsset() override = default;

        ScriptAsset(const ScriptAsset& rhs) = delete;
        ScriptAsset& operator=(const ScriptAsset& rhs) = delete;

        //////////////////////////////////////////////////////////////////////////
        // Script data
        const AZStd::vector<char>& GetScriptBuffer() { return m_scriptBuffer; }
        IO::MemoryStream CreateMemoryStream() { return IO::MemoryStream(m_scriptBuffer.data(), m_scriptBuffer.size()); }
        IO::ByteContainerStream<AZStd::vector<char>> CreateWriteStream() { return IO::ByteContainerStream<AZStd::vector<char>>(&m_scriptBuffer, m_scriptBuffer.size()); }

        const char* GetDebugName() { return m_debugName.empty() ? nullptr : m_debugName.c_str(); }

    private:
        // This will be the buffer of either the precompiled script or the source (depending on asset selected)
        AZStd::vector<char> m_scriptBuffer;
        // Debug name of the script. Will be empty if script is precompiled
        AZStd::string m_debugName;

        friend class ScriptSystemComponent;
        friend UnitTest::ScriptComponentTest;
    };
}

==> 2210.0.tar.gz: o3de/Code/Framework/AzCore/AzCore/Script/ScriptAsset.h <==
/*
 * Copyright (c) Contributors to the Open 3D Engine Project.
 * For complete copyright and license terms please see the LICENSE at the root of this distribution.
 *
 * SPDX-License-Identifier: Apache-2.0 OR MIT
 *
 */
#pragma once

#include <AzCore/Asset/AssetCommon.h>
#include <AzCore/IO/GenericStreams.h>
#include <AzCore/IO/ByteContainerStream.h>
#include <AzCore/std/containers/vector.h>

namespace UnitTest
{
    class ScriptComponentTest;
}

namespace AZ
{
    class ReflectContext;
    class ScriptAsset;

    class LuaScriptData
    {
    public:
        AZ_CLASS_ALLOCATOR(LuaScriptData, AZ::SystemAllocator, 0);
        AZ_TYPE_INFO(LuaScriptData, "{C62098FE-8E3F-4DD3-88F8-B11FD2609A43}");

        static void Reflect(AZ::ReflectContext* context);

        AZStd::string m_debugName;
        AZStd::vector<AZ::Data::Asset<ScriptAsset>> m_dependencies;
        AZStd::vector<char> m_luaScript;

        IO::MemoryStream CreateScriptReadStream();
        IO::ByteContainerStream<AZStd::vector<char>> CreateScriptWriteStream();
        const char* GetDebugName();
        const AZStd::vector<char>& GetScriptBuffer();
    };

    /**
    * Script Asset - contains the source code for a script
    */
    class ScriptAsset
        : public Data::AssetData
    {
    public:
        AZ_CLASS_ALLOCATOR(ScriptAsset, AZ::SystemAllocator, 0);
        AZ_RTTI(ScriptAsset, "{82557326-4AE3-416C-95D6-C70635AB7588}", Data::AssetData);

        static const u32 CompiledAssetSubId = 1;

        ScriptAsset(const Data::AssetId& assetId = Data::AssetId());
        ~ScriptAsset() override = default;

        LuaScriptData m_data;

    private:
        friend class ScriptSystemComponent;
        friend UnitTest::ScriptComponentTest;
    };
}
